package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(W``````````0```````
M`,&8``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*V8````````K9@`
M```````0``````$````&````````N[````````"[L````````+NP````````
M!-@````````%`````````!```````@````8```````"[P````````+O`````
M````N\`````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````I=@```````"EV````````*78`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+NP````````N[``````
M``"[L`````````10````````!%```````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`%F5"YYS"?RP[D]GN+ZT@Z0)^[T(````$````$```
M``%'3E4```````````,````"```````````````1````1`````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D"`(F""`(`ND$0@(@`````````1````$<```!*
M````2P```%,```!4````50````````!7````6````%D```!:````6P```%T`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'ZF\-/F=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,
M%0N7.@V;G*E_"@*GX%">&FM)^^"C````````````````````````````````
M```````````#```+````````&9```````````````WL2````````````````
M`````````````J82`````````````````````````````(P1````````````
M`````````````````<,2`````````````````````````````@T2````````
M`````````````````````HT2`````````````````````````````+T2````
M`````````````````````````DD2`````````````````````````````<H2
M``````````````````````````````$@````````````````````````````
M`H82`````````````````````````````&<2````````````````````````
M`````;82`````````````````````````````,82````````````````````
M`````````M@2`````````````````````````````842````````````````
M`````````````?T2`````````````````````````````2D2````````````
M`````````````````6H2`````````````````````````````)02````````
M`````````````````````!`@`````````````````````````````KX2````
M`````````````````````````2`2`````````````````````````````(H1
M`````````````````````````````3<2````````````````````````````
M`"P@`````````````````````````````)T2````````````````````````
M`````K`2`````````````````````````````4T2````````````````````
M`````````.$6`````````````````````````````/02````````````````
M`````````````7X2`````````````````````````````EP2````````````
M`````````````````0\2`````````````````````````````LD2````````
M`````````````````````+,2`````````````````````````````%@B````
M`````````````````````````=<2`````````````````````````````;$2
M`````````````````````````````3X2````````````````````````````
M`=$2`````````````````````````````6,2````````````````````````
M`````:(2`````````````````````````````I@2````````````````````
M`````````BX2`````````````````````````````'D2````````````````
M`````````````7<2`````````````````````````````>@2````````````
M`````````````````)P2`````````````````````````````-H2````````
M`````````````````````AD2`````````````````````````````;X2````
M`````````````````````````GH2`````````````````````````````JL2
M`````````````````````````````?82````````````````````````````
M`FT1`````````````````````````````8P2````````````````````````
M`````*02`````````````````````````````,P2````````````````````
M`````````002`````````````````````````````542````````````````
M`````````````*L2`````````````````````````````CH2````````````
M`````````````````$82`````````````````````````````902````````
M`````````````````````9L1`````````````````````````````X02```-
M````````8*``````````W````]D2```-````````55`````````(^@```%,2
M```-````````(-`````````"E````OL2```-````````1.``````````$@``
M`QD2```-````````7E`````````"3````_\2```-````````10`````````#
MP@```[\0```7````````P(@``````````````PP2```-````````2-``````
M````0@```R\2```-````````4&``````````A````Y`1```/````````91``
M````````!````ZP2```-````````8?`````````!2@```[<2```-````````
M0Z``````````1````]00```7````````P+```````````````^T2```-````
M````4Y`````````!M@``!!82```-````````4/``````````A@```Y\0```6
M````````P````````````````U,2```-````````22`````````!E@```^80
M```7````````P(@`````````````!`P1```6````````P(``````````"```
M`Z42```-````````(W```````````````\L2```-````````88``````````
M8@```Z$@```6````````P````````````````VD2```-````````4U``````
M````.@```ST2```-````````0_``````````[@```U\2```-````````8T``
M```````!A```!!X2```-````````2L`````````%F@!?7V=M;VY?<W1A<G1?
M7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-
M0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!?
M7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`%]?96YV:7)O;@!S
M=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A9&1I<C8T`&-L;W-E
M9&ER`')M9&ER`%]?<W!R:6YT9E]C:&L`=6YL:6YK`%!,7V-U<G)E;G1?8V]N
M=&5X=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=84P!097)L7VYE=UA37V9L
M86=S`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`;65M8VAR`%!E<FQ?<W9?<V5T
M<'9N`')E86QL;V,`7U]M96UM;W9E7V-H:P!G971P:60`7U]M96UC<'E?8VAK
M`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<G)C:'(`;65M8W!Y`'-T9&5R<@!?
M7W9F<')I;G1F7V-H:P!E>&ET`&QS965K-C0`<F5A9`!G971U:60`<W1R<W1R
M`&UK9&ER`%]?97)R;F]?;&]C871I;VX`7U]F<')I;G1F7V-H:P!O<&5N-C0`
M4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?;6=?<V5T`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,7V1O7W5N9'5M<`!097)L7W-A9F5S
M>7-M86QL;V,`<&5R;%]P87)S90!P97)L7V1E<W1R=6-T`'!E<FQ?9G)E90!0
M97)L7W-Y<U]T97)M`'!E<FQ?86QL;V,`<&5R;%]C;VYS=')U8W0`<&5R;%]R
M=6X`;&EB<&5R;"YS;RXU+C,X`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I
M;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])
M3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`
M7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R
M7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?
M,BXS,P!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C(`````````
M`@`!``(``@`!``$``@`!``(``0`"``,``@`"``$``@`!``$`!``"``$``0`"
M``(``@`!``4``0`"``$``0`"``$``0`!``(``@`"``(``0`"``(`!@`!``$`
M!@`"``8`!0`"``$``@`!``(``@`!``(``@`&``$`!``"``$`!P`"``(``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``````````$`!@```O$````0``````:6D;0````'```$*P```!`-:6D4
M````!@``!#8````0!I:1LP````4```1`````$`EI&70````$```$2P```!`)
M:1ER`````P``!%<````0#6EI$@````(```1C`````````````+NP````````
M``P````````DD````````+NX``````````P````````D0````````+^H````
M``````P```````!>4````````+_H``````````P```````#`@````````+_X
M``````````P````````@T````````,`(``````````P```````#`"```````
M`,`@``````````P```````"E?@```````,`H``````````P```````!E;```
M`````,`X``````````P```````!F#````````,!```````````P```````!F
M$````````,!(``````````P```````"E<@```````,!0``````````P`````
M``!E<@```````,!8``````````P```````"E>@```````,!H``````````P`
M``````"E8@```````,!P``````````P```````"E:````````,"`````````
M``P```````!G\@```````+^0````!`````H``````````````````+^8````
M"0````H``````````````````+^@````"P````H``````````````````+^P
M````%@````H``````````````````+^X````&P````H`````````````````
M`+_`````'P```#@``````````````````+_(````(`````H`````````````
M`````+_0````(@````H``````````````````+_8````)@````H`````````
M`````````+_@````.0````H``````````````````+_P````0P````H`````
M`````````````+W8`````@````L``````````````````+W@`````P````L`
M`````````````````+WH````!0````L``````````````````+WP````!@``
M``L``````````````````+WX````!P````L``````````````````+X`````
M"`````L``````````````````+X(````"@````L``````````````````+X0
M````#`````L``````````````````+X8````#0````L`````````````````
M`+X@````#@````L``````````````````+XH````#P````L`````````````
M`````+XP````$`````L``````````````````+XX````$0````L`````````
M`````````+Y`````$@````L``````````````````+Y(````$P````L`````
M`````````````+Y0````%`````L``````````````````+Y8````%0````L`
M`````````````````+Y@````%P````L``````````````````+YH````&```
M``L``````````````````+YP````&@````L``````````````````+YX````
M'`````L``````````````````+Z`````'0````L``````````````````+Z(
M````'@````L``````````````````+Z0````(0````L`````````````````
M`+Z8````(P````L``````````````````+Z@````)`````L`````````````
M`````+ZH````)0````L``````````````````+ZP````)@````L`````````
M`````````+ZX````)P````L``````````````````+[`````*`````L`````
M`````````````+[(````*0````L``````````````````+[0````*@````L`
M`````````````````+[8````*P````L``````````````````+[@````+```
M``L``````````````````+[H````+0````L``````````````````+[P````
M+@````L``````````````````+[X````+P````L``````````````````+\`
M````,`````L``````````````````+\(````,0````L`````````````````
M`+\0````,@````L``````````````````+\8````,P````L`````````````
M`````+\@````-`````L``````````````````+\H````-0````L`````````
M`````````+\P````-@````L``````````````````+\X````-P````L`````
M`````````````+]`````.`````L``````````````````+](````.@````L`
M`````````````````+]0````.P````L``````````````````+]8````/```
M``L``````````````````+]@````/0````L``````````````````+]H````
M/@````L``````````````````+]P````/P````L``````````````````+]X
M````0`````L``````````````````+^`````00````L`````````````````
M`+^(````0@````L``````````.MO\#``)+D$`!^G^_]@XQ#P```DP,```%(.
MP!```%+[XQ`0```$N0(`$:>$``,-X>-`\1``!.MO\-``!`?T``#C$/`X`"3`
M$```4?72!_`P$`CC$!`0``0'\0<`!P`'`,`0``!1].,0$```!`?Q#1#C$!`,
M`!3`]/___^4`````P!```%'HXQ`0```$!_$-$.,0$`P`%,#T____U0```!C`
M$```4=SC$!````0'\0T0XQ`0#``4P/3____%````,,`0``!1T.,0$```!`?Q
M#1#C$!`,`!3`]/___[4```!(P!```%'$XQ`0```$!_$-$.,0$`P`%,#T____
MI0```&#`$```4;CC$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!1K.,0
M$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```%&@XQ`0```$!_$-$.,0$`P`
M%,#T____=0```*C`$```493C$!````0'\0T0XQ`0#``4P/3___]E````P,`0
M``!1B.,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!```%%\XQ`0```$!_$-
M$.,0$`P`%,#T____10```/#`$```47#C$!````0'\0T0XQ`0#``4P/3___\U
M```!",`0``!19.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```%%8XQ`0
M```$!_$-$.,0$`P`%,#T____%0```3C`$```44SC$!````0'\0T0XQ`0#``4
MP/3___\%```!4,`0``!10.,0$```!`?Q#1#C$!`,`!3`]/___O4```%HP!``
M`%$TXQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```42CC$!````0'\0T0
MXQ`0#``4P/3___[5```!F,`0``!1'.,0$```!`?Q#1#C$!`,`!3`]/___L4`
M``&PP!```%$0XQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```403C$!``
M``0'\0T0XQ`0#``4P/3___ZE```!X,`0``!0^.,0$```!`?Q#1#C$!`,`!3`
M]/___I4```'XP!```%#LXQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`$```
M4.#C$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!0U.,0$```!`?Q#1#C
M$!`,`!3`]/___F4```)`P!```%#(XQ`0```$!_$-$.,0$`P`%,#T___^50``
M`EC`$```4+SC$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!0L.,0$```
M!`?Q#1#C$!`,`!3`]/___C4```*(P!```%"DXQ`0```$!_$-$.,0$`P`%,#T
M___^)0```J#`$```4)CC$!````0'\0T0XQ`0#``4P/3___X5```"N,`0``!0
MC.,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```%"`XQ`0```$!_$-$.,0
M$`P`%,#T___]]0```NC`$```4'3C$!````0'\0T0XQ`0#``4P/3___WE```#
M`,`0``!0:.,0$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```%!<XQ`0```$
M!_$-$.,0$`P`%,#T___]Q0```S#`$```4%#C$!````0'\0T0XQ`0#``4P/3_
M__VU```#2,`0``!01.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!```%`X
MXQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```4"SC$!````0'\0T0XQ`0
M#``4P/3___V%```#D,`0``!0(.,0$```!`?Q#1#C$!`,`!3`]/___74```.H
MP!```%`4XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`$```4`CC$!````0'
M\0T0XQ`0#``4P/3___U5```#V,`0``!/_.,0$```!`?Q#1#C$!`,`!3`]/__
M_44```/PP!```$_PXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```3^3C
M$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!/V.,0$```!`?Q#1#C$!`,
M`!3`]/___14```0XP!```$_,XQ`0```$!_$-$.,0$`P`%,#T___]!0``!%#`
M$```3\#C$!````0'\0T0XQ`0#``4P/3___SU```$:,`0``!/M.,0$```!`?Q
M#1#C$!`,`!3`]/___.4```2`P!```$^HXQ`0```$!_$-$.,0$`P`%,#T___\
MU0``!)C`$```3YSC$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!/D.,0
M$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```$^$XQ`0```$!_$-$.,0$`P`
M%,#T___\I0``!.#`$```3WCC$!````0'\0T0XQ`0#``4P/3___R5```$^,`0
M``!/;.,0$```!`?Q#1#C$!`,`!3`]/___(4```40ZV_P,``DLD\`H+D$`._K
MJ@`@``WC\/\X_W'CX/```"2R3P"AN00`O^,PL*@`).-`L*``)%`@L+32![#`
MH"A!0+"@03"PJ$$@L+3`Y?___ZO$2```3SS$*```3U6Y!``TP.4``"'0Q!@`
M`$]5E0`0`*>$`+G`,```3S[C4#````18D+"TXV6@```$[(D`!`#8E@-DBKD4
M`.CK+@`#``VGF@`#P.7___[OXQ"PJ``$P#```$^!XP`0```$XV`P```$XP`@
M```D6("PM+D$`%+C8%`0`"3$*P``3WK`0```(R+C0%`8`"3`(```(QKC(%`(
M`"3LC`#%`7[L2``#`-CL"/__`-A!X!`(IR@`!*<!``&G=`""B````;D4`&+K
M1@`#``WC8.````3L$@`!`-CC9%```"2Y%``QZQ,``P`-XS#@"``$IRH``N,Q
M4```)*?K`!"G!O_C[.@``P#8Q"@``$\^N10`CKD4`$GKF``#``U!Z5``Y4C@
M````IVD``,`P```.,<#E___\#NPH`%0`?L0H``!/)$%@L+S`Y?___>.Y!``V
MN00`@L`@```AH\#E```,2>PH`$<`?,0H``!/#\#E___[P,#E___\_=4'L,"@
M**=T`%FY!``HZV^P^``$!_[`Y?___*_$*P``3OCL*`!.`'S`Y?___2;`,```
M3GOC(#````3C0J````22`$E^I_3_->,PX```!*<H``7C,%`@`"1!X!`0["3_
M=F!VI_3_E,0H``!.T\#E___\)*?T_ZG`4```3L?C(%````*GA``'P.4``!Z_
MI_3_L;D$`#;`(```(1_`Y0``"^W$*P``3K+L*/^D`'RG]/_MI^@`!*?T_V[`
MY?___8ZG*0`!P.7___T9!P<'!P<'!P<'!P<'04#P".,P\```!*<)__"Y@`#P
MI_O_4-<'\`#P`.OO\*``)$%P\*"G:0``IUD``,`@``!.+>,@(```!,#E___^
M<P``!P<'!P<'!P<'!P<'!P?`$```3F3`(```3F'L$@`*@&3$&```3>_L&``$
M`'P'\0?^!P<'!P<'!P<'!P<'!P?`$```3DS`(```3DFY"0`2ZP$``P`*ZS$`
M/P`,N0@`,.LS``$`"NPX``T`?,08``!-SNP8``<`?,`@``!.,`?Q!_X'!P<'
M!P<'!P<'!P<'!^N_\%@`),"P``!.(>/P_V#_<94`L`"G=``5P!```$V_XQ`0
M```"IX0`",0H``!-S\#E___\<,#E____I9(!L`#KO_#X``0'_@<'!P<'!P<'
MP/3___^P!P<'!P<'!P<'!^MO\#``)+)/`!"Y!`#OZS$`(``-LD\`,>/P_,C_
M<>/@\```)+D$`+_C,+"@`"3G8`\/`$1!H+"PT@>S,#`HN00`:D%0(#BY!`!Z
MITD`!.<`4``P!J=;`!#G(``@,#CG$&```&CG0A``,&'G,A``,&#G0'``,`[G
M,'`0,`ZG>P`@IT?_Y^?`H!`X!N?@H"`X!N<@H#`X!N=0#P\`1*<)`"#G`&!H
M.`;G<@``!%;G(&!`.`;G0&``.`:G:P`0YV(```YMYQ9```YMYS'```YMYU,`
M`3PPYW,`'SPXYX5P``YJYZA0``QHYZ!@<#@.Y\X```Q6Y^<```A6IP?_U./@
M(`@`!..@(!``!.-`(!@`!.-0(```!.-`L*@`)./0L+@`!.,PL+``!+GG0`JY
M@``.N8(`!,+:6H)YF>QU(+\E6;D(`-3L=2`Z!5;".EJ">9GC0+#```3C,"`@
M``BY"`!SN0@`<.,`L,@`!.N.``(`#,(*6H)YF>R.`"$>5L)*6H)YF;D(`$KL
MF""_`%7K-0`"``SL-0`A'E:YYS!H[(<@OP!5N8``:+F"`&FY"`!DN>B00.,`
ML-``!+GGD!K""EJ">9FY@``5N8(`&KD(`!WLUSN_)5GLV``Z!5:Y"``=['$@
MOP!5[!$[OR59[!<`.@56N0@`%NN8``(`#.QC(+\`5>R8`"$>5NS1.[\E6>R!
M(+\`5;F"`#FYY'`3N8(`%KD(`!2YZ&!`XP"PV``$N00`/<(*6H)YF>PX`#H%
M5KD(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E;L<2"_`%6Y@@"3Y]`/#PA$
MN>2`&;F"`!:Y"``4N>A@0.,`L.``!+D$`)W""EJ">9GLEP`Z!5:Y"``9[&,@
MOP!5[-$[OR59ZY@``@`,[)@`(1Y6[($@OP!5N8(`.;GD<!.Y@@`6N0@`%+GH
M8$#C`+#H``2Y!``]P@I:@GF9[#@`.@56N0@`$^QI(+\`5>S1.[\E6>LW``(`
M#.PW`"$>5NQQ(+\`5;F"`).YY(`9N8(`%KD(`!2YZ&!`XP"P\``$N00`G<(*
M6H)YF>R7`#H%5KD(`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E;L@2"_`%6Y
M@@`YN>1P$[F"`!:Y"``4N>A@0.,`L/@`!+D$`#W""EJ">9GL.``Z!5:Y"``3
M[&D@OP!5[-$[OR59ZS<``@`,[#<`(1Y6['$@OP!5N8(`D[GD@!FY@@`6N0@`
M%+GH8$#C`+$```2Y!`"=P@I:@GF9[)<`.@56N0@`&>QC(+\`5>S1.[\E6>N8
M``(`#.R8`"$>5NR!(+\`5;F"`#FYY'`3N8(`%KD(`!2YZ&!`XP"Q"``$N00`
M/<(*6H)YF>PX`#H%5KD(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E;L<2"_
M`%6Y@@"3N>2`&;F"`!:Y"``4N>A@0.,`L1``!+D$`)W""EJ">9GLEP`Z!5:Y
M"``9[&,@OP!5[-$[OR59ZY@``@`,[)@`(1Y6[($@OP!5N8(`.;GD<!.Y@@`6
MN0@`%+GH8$#C`+$8``2Y!``]P@I:@GF9[#@`.@56N0@`$^QI(+\`5>S1.[\E
M6>LW``(`#.PW`"$>5NQQ(+\`5;F"`).YY(`9N8(`%KD(`!2YZ&!`XP"Q(``$
MN00`G<(*6H)YF>R7`#H%5KD(`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E;L
M@2"_`%6Y@@`YN>1P$[F"`!:Y"``4N>A@0.,`L2@`!+D$`#W""EJ">9GL.``Z
M!5:Y"``3[&D@OP!5[-$[OR59ZS<``@`,[#<`(1Y6['$@OP!5N8(`D[GD@!FY
M@@`6N0@`%+GH8$#C`+$P``2Y!`"=P@I:@GF9[)<`.@56N0@`&>QC(+\`5>S1
M.[\E6>N8``(`#.R8`"$>5NR!(+\`5;F"`#FYY'`3N8(`%KD(`!2YZ&!`XP"Q
M.``$N00`/>PX`#H%5NQI(+\`5;D(`!/""EJ">9GK-P`"``SL-P`A'E:Y@@"3
M['$@OP!5[-$[OR59N>2`&;D$`)VY@@`6[)<`.@56N0@`%+GH8$#C`+%```2Y
M"``9[&,@OP!5ZY@``@`,[)@`(1Y6N8(`.>R!(+\`5>S1.[\E6<(*6H)YF;GD
M<!.Y!``]N8(`%NPX`#H%5KD(`!2YZ&!`N0@`$^QI(+\`5>LW``(`#.PW`"$>
M5N-PL4@`!+F"`).Y@`"8N8(`EKD(`)3K2``"``SL2``A'E;C@+%0``3">EJ"
M>9G"BF[9ZZ&YZ&`'[-$[OR59[-$@.@56P!H`````N0@`G>QS(+\`5;F"`#2Y
M@``QN8(`-[D(`'BY"``PXP"Q6``$ZX$``@`,[($`(1Y6N>>`%+F"`!GL:3N_
M)5FY&@!Q[&D@.@56XQ"Q8``$N0@`-L(*;MGKH>S3.[\E6;D$`&#LTR`Z!5:Y
M&@!DN0@`?>Q)(K\^6>S7.[\E6>Q)`B$>5NS7(#H%5KGG0`C"&F[9ZZ&Y@@`#
MN1H`&+D$`);C@+%H``3L8R*_/EGL8P(A'E:YYV`TN8(`-[D:`)"Y&@`3N0@`
MG>,PL7``!.S9.[\E6>S9(#H%5L**;MGKH;D(`!VY&@"$[-<BOSY9[$DBOSY9
M[-<"(1Y6[$D"(1Y6N>?0=KF"`'FYYT"=N8(`D>P!.[\E6<(Z;MGKH>P!(#H%
M5KD:`#:Y&@`YXY"Q>``$N1H`A^QA(K\^6;D(`(#L80(A'E;L"#N_)5GC$+&`
M``3L""`Z!5:Y"``PPIINV>NAN>=@=,(:;MGKH;F"`'BY&@`4[$@BOSY9[$@"
M(1Y6XX"QB``$N1H`G<**;MGKH;D:`)>Y&@"&N>=`=NS3.[\E6;F"`'/LTR`Z
M!5:Y&@`7N0@`G>QC(K\^6>P).[\E6>QC`B$>5NP)(#H%5KD(`!#L,3N_)5GL
M,2`Z!5:SP0!SXS"QD``$N>=@!,(Z;MGKH;F"``FY&@`T['DBOSY9L\T`1^QY
M`B$>5N.0L9@`!+D:`(#"FF[9ZZ&Y"`"$N>=P!KD:`):Y@@`![-@[OR59N1H`
M,.S8(#H%5NQA(K\^6;D(`#WL80(A'E;L$SN_)5GL$R`Z!5:YYV#7XT"QH``$
MN8(`V+D:`)VY"`"1[!@BOSY9[!@"(1Y6XX"QJ``$N><0UL)*;MGKH;F"`-.Y
M&@!'[`D[OR59N1H`3>P)(#H%5L**;MGKH;D(`$"Y&@"&[&,BOSY9[&,"(1Y6
M[#0[OR59[#0@.@56L\$`$^,PL;``!+GG8`'".F[9ZZ&Y@@`)N1H`,>QY(K\^
M6;/-`!'L>0(A'E;CD+&X``2Y&@"`PIINV>NAN0@`@;GG<`:Y&@"6[-@[OR59
M[-@@.@56L\$`3;/-`&2Y@@`$[-0BOSY9N1H`,.S4`B$>5KD(`#:YY]`'[$,[
MOR59N8(`".Q#(#H%5KD:`)"Y"`"4[&D[OR59[&D@.@56XQ"QP``$L\$`5N-@
ML<@`!+/-``7"&F[9ZZ'L2"*_/EFY&@`7[$@"(1Y6PFINV>NAN>=`C;D:`&VY
M@@"#[-,BOSY9N1H`&.S3`B$>5KD(`!#L,3N_)5GL,2`Z!5:SP0!SXS"QT``$
MN>?0=,(Z;MGKH;D:`#2SS0!'N8(`>>R)(K\^6;D:`&?LB0(A'E:Y"`!DN>>`
MG>P&.[\E6;F"`)'L!B`Z!5:Y&@`Y[$$BOSY9N0@`,.Q!`B$>5NP3.[\E6>P3
M(#H%5K/!``'C$+'@``2YYT`(PAINV>NAXW"QV``$N1H`&+/-`("Y@@`&PGIN
MV>NAN1H`?;D:`'"Y"`!X[(<@OP!5[)<[OR59[)@`.@56[-8BOSY9XP"Q\``$
M[-8"(1Y6N>?09+F"`&.Y&@`6N0@`&>.0L>@`!.QC(K\^6<*:;MGKH>QC`B$>
M5KD:`)2YYV`][$$[OR59N8(`-\(*CQN\W.QQ(+\`5;D:``WK&``"``SL&``A
M'E;LT2"_`%6YY-"&[$<`.@56N1H`D[GF$#:Y@``WN8$`...`L?@`!+D(`)2Y
M"``P[$D@OP!5XP"R```$[)D[OR59[)0`.@56PHJ/&[S<N0@`.;D:`(;KEP`"
M``SLEP`A'E:YY-!YN8$`&;F``!2Y@0`7N0@`&.QC(+\`5<(*CQN\W.PS.[\E
M6;D(``WL-@`Z!5:Y"``QZQ0``@`,[!0`(1Y6[-$@OP!5N>30B;GF$$FY@`!&
MN8$`2.R#(+\`5;D(`$#L,SN_)5GC`+((``3L.``Z!5:Y"``T[',@OP!5[$,[
MOR59XS"R$``$P@J/&[S<N1H`">N6``(`#.R6`"$>5KGDT&FY@0`9N8``&+F!
M`!:Y"``0[$<`.@56PCJ/&[S<N0@`0;GHT`/K&``"``SL&``A'E;LT2"_`%6Y
MY-")N>80:;F``&>Y@0!H[(0@OP!5N0@`8.Q$.[\E6>,`LA@`!.Q(`#H%5KD(
M`$;L9""_`%7L-#N_)5GC0+(@``3""H\;O-RY&@`)PDJ/&[S<ZY<``@`,[)<`
M(1Y6N>30>;F!`!FY@``8N8$`%[D(`!"YZ-`$[#8`.@56N0@`,>L8``(`#.P8
M`"$>5NS1(+\`5;GF$(FYY-!YN8``AKF!`(>Y"`"`XP"R*``$XW"R,``$P@J/
M&[S<N1H`">Q#(+\`5<)ZCQN\W.PS.[\E6>PT`#H%5KD(`#CKA@`"``SLA@`A
M'E:YY-!HN8$`&+F``!2Y@0`6N0@`$+GHT`?LDR"_`%7L,SN_)5GL.0`Z!5:Y
M"``QZQ0``@`,[',@OP!5[!0`(1Y6[#,[OR59[-$@OP!5N>802+GDT&BY@`!)
M[#<`.@56N8$`1KD(`$#C`+(X``2Y"``T[$,@OP!5[&,[OR59XS"R0``$P@J/
M&[S<N1H`".N)``(`#.R)`"$>5KGF@)&YY-`8[&0`.@56N8``E\(ZCQN\W+F!
M`)&Y"``]L\$`$[D(`)"SS0`!N0@`ENL7``(`#.P7`"$>5NS1(+\`5;GDT'BY
MYA`X[&D[OR59N8``-+F!`#?L>2"_`%7CD+)(``3L9P`Z!5:Y"``PPIJ/&[S<
MN0@`-K/!`$FSS0!DZY0``@`,N1H`:.R4`"$>5NQ#(+\`5;GDT`FY@0`9N8``
M%[F!`!"Y"``6XV"R4``$[#,[OR59PFJ/&[S<N>C0!NPT`#H%5KD(`#'K%P`"
M``SL%P`A'E;LT2"_`%6YYA!YN>30B;F``'2Y@0!XN0@`<.,`LE@`!.R#(+\`
M5<(*CQN\W.PS.[\E6;D:``GL.``Z!5:YZ#"7ZS0``@`,['D@OP!5[#0`(1Y6
M[$D[OR59XY"R8``$N>308[F!`!/"FH\;O-RY@``8N8$`%KD(`!"YZ-`)[$<`
M.@56N0@`0>L8``(`#.P8`"$>5NS1(+\`5;GF$&.YY-"#N8``9[F!`&BY"`!@
MXP"R:``$[(0@OP!5P@J/&[S<[$0[OR59N1H``^Q(`#H%5KGH0#;L8R"_`%7L
M0SN_)5GC,+)P``3KEP`"``S".H\;O-SLEP`A'E:YY-!YN8$`&;F``!BY@0`7
MN0@`$+GHT`/C,+)X``3L1@`Z!5:Y"`!!ZQ@``@`,[!@`(1Y6['$@OP!5N>1P
MB;GF$-G".H\;O-RY@`#6N1H`.;F!`-CKE@`"``SLA""_`%7LE@`A'E:Y"`#0
M[$0[OR59[$@`.@56N0@`3>QD.[\E6>S4(+\`5;GFD$&Y!``6XV"R@``$N>1P
M">P=`#H%5KF``$C":H\;O-RY@0!`N0@`0[GH<#:Y"`!!ZQ@``@`,[!@`(1Y6
M['$@OP!5N>80B;GD<&FY@`"-N8$`AKD(`(/C,+*(``3K;0`"``S".H\;O-RY
M&@`YL\$``^,PLI``!.P$.[\E6<(ZRF+!UNP$(#H%5KD$`):SS0!@N0@`@.R=
M`"$>5NS8.[\E6;GD<`GLV"`Z!5:YZ'!SL\$`%[/-`#'`2@````"Y@0`9N8``
M%+F!`!"Y"``6N0@`'>S1.[\E6>S1(#H%5NMT``(`#.,`LI@`!.QT`"$>5KGG
M<$FY@@!(N1H`-+D(`#WCT+*@``3""LIBP=;L:"*_/EFY&@`)[&@"(1Y6PMK*
M8L'6N>=@1[D:`->Y@@!![(,[OR59N1H`!.R#(#H%5KD(`(#LF#N_)5GLF"`Z
M!5;L<2*_/EFSP0!Y['$"(1Y6XY"RJ``$N00`';/-`->YYW!&PIK*8L'6N8(`
M0[D:`):Y&@`4[&,BOSY9N0@`'>QC`B$>5NPQ.[\E6>PQ(#H%5KGG8`?C0+*P
M``2Y@@`(N1H`D+D(`)/L."*_/EGL.`(A'E;C@+*X``2YYS`&PDK*8L'6N8(`
M`;D:`$?LV3N_)5FY&@!`[-D@.@56PHK*8L'6N0@`3;D:`(;L82*_/EGL80(A
M'E;L%#N_)5GL%"`Z!5:SP0`!XQ"RP``$N>=@T\(:RF+!UKF"`-FY&@`3['DB
MOSY9L\T`,.QY`B$>5N.0LL@`!+D:`(W"FLIBP=:Y"`"#N>=PUKD:`):Y@@#4
M[`@[OR59N1H`'>P((#H%5NQD(K\^6;D(`!#L9`(A'E;L03N_)5GL02`Z!5:Y
MYV`'XS"RT``$N8(`"+D:`)"Y"`"4[$@BOSY9[$@"(1Y6XX"RV``$N>=`!L(Z
MRF+!UKF"``&Y&@`W[-D[OR59N1H`,.S9(#H%5L**RF+!UKD(`#VY&@"&[&$B
MOSY9[&$"(1Y6[!,[OR59[!,@.@56L\$`4>,0LN``!+GG8-3"&LIBP=:Y@@#9
MN1H`%.QY(K\^6;/-`$7L>0(A'E;CD++H``2Y&@"-PIK*8L'6N0@`A+GG<-:Y
M&@"6N8(`T^P(.[\E6;D:`!WL""`Z!5;L8R*_/EFY"``0[&,"(1Y6[#$[OR59
M[#$@.@56N>=@!^-`LO``!+F"``BY&@"0N0@`D^PX(K\^6>PX`B$>5N.`LO@`
M!+GG,`;"2LIBP=:Y@@`!N1H`1^S9.[\E6;D:`$#LV2`Z!5;"BLIBP=:Y"`!-
MN1H`ANQA(K\^6>QA`B$>5NP4.[\E6>P4(#H%5K/!``'C$+,```2YYV#3PAK*
M8L'6N1H`$[/-`#"Y@@#9['DBOSY9N1H`C>QY`B$>5KD(`(/CD+,(``3C,+,0
M``3L"#N_)5GL""`Z!5:YYW#6PIK*8L'6N8(`U+D:`):Y&@`=[&0BOSY9N0@`
M$.QD`B$>5L(ZRF+!UKGG8`>Y&@`WXW"S&``$[$$[OR59[$$@.@56N8(`".S8
M(K\^6;D:`)#LV`(A'E:Y"`"4N>?0ANQ).[\E6;F"`('L22`Z!5:Y&@`XPGK*
M8L'6N0@`-+D:`';L82*_/EGL80(A'E;L$SN_)5GL$R`Z!5:SP0!1XQ"S(``$
MN>=@3>R)(K\^6;F"`$GLB0(A'E:YYX"6N8(`D\(:RF+!UKD:`!VY&@`9[),B
MOSY9[),"(1Y6XS"S*``$L\T`U;D:`'3".LIBP=:SP0!SL\T`1[D(`'VYYY`X
M[-<@OP!5N8(`-^P'.[\E6;D(`%3L#0`Z!5:Y&@!6N0@`$.QQ(+\`5;D:`%/L
M83N_)5GL9P`Z!5:Y"`!EN0@`?N.0L*@`".>6<``(8NOM``(`#.?YT``.:.SM
M`"$>5KGHH*[GNI``"&+C@"`@``CG"]``#FC`B@````#C@"`@`"3G\"``.`[G
M`"`0.`[C(+"@``35![,P("BG=``&ZV^S:``$!_[`Y?__\;@'!P<'!P<'!P<'
MZV_P,``DN00`[^/P_V#_<>/@\```)+D$`+_L*`!<`'S$&```0C#C8!````*G
MA`!3XP`@``"4N00`<KD$`-.Y!`""E0`@`*>$`$[L"``,/7Y!@(`!XP"```"4
ME0"``*=T__8;A^.08````J>$`!^Y%`"(N00`IKD$`$BY!``WN00`*<#E___P
M+^PF``D`?D$HD`"5/2``IX0`#T&@H`CCD*````*G=/_IN00`*>MOL-``!`?^
MN>E@.D&8D`'K0P`#``I00-``N00`*>MOL-``!`?^IYD``+D$`"GK;[#0``0'
M_J>(``"G]/^_!P<'!P<'ZY_P2``DLD\`H+D$`._KJ@`@``VR3P"AX_#^R/]Q
MX^#P```DN00`DKD$`+]!,+"@T@>Q,*`HP.7___%-["8`(0!^&!)8(+"XISA`
M`,`K``#P`.PC``B`=J4/H`#L(``38':Y!``IISD``L#E___QLQ`2IQK__X@0
M`!^G]``$IQ@``-4'L3"@*+D4`"&G=``&ZY^Q@``$!_[`Y?__\.P'!^MO\#``
M)+)/`)"Y!`#OZYD`(``-LD\`D>/P_L#_<>/@\```)+D$`+_2![$XD"CL*``)
M`'RY!`!BE0`@`*=T``O5![$XD"BG=`"'ZV^Q<``$!_[`Y?__\:^Y!`"B["C_
M\@!\N00`*L#E___P%>PH`%H`?$&`(!.5+B`3IW0`!I4`@`&GA/_PE2X@$Z>$
M`%>G&0``[$8\OP!5IX0`6J<Y``^Y"0`TYP-@```WIQL`$.<@`#``@:>$``SG
M`6``0`:G&P`0YR``,`"!IW3_^.<"``<`(4%0,`&YA`!PN2``<[GB(!6G)``U
MX^%_\/]Q[$@\OP!5IQD``*>$`#*G.0`/N0D`-.=#(!,`-Z<;`!#G9$`P`(&G
MA``HYT$@$T`&I_3_]KD$`"K`Y?__[F:Y!``FP.7__^ZQI_3_AI4N@`&G=/^I
ME0"``J>$_X^G]/^CISD`#Z?T_[3`Y?__\#ZG.0`/I_3_W.<&``<`(4%0,`&Y
MA`!PN2``<[GB(!6G)/_QXR%_\/]Q&N*GZ@`"N10`?KD$`"?`Y?__[E#C@/"@
M`"2G.0`"N00`@KD$`$?`4```$V;`Y?__\-&Y!``H03"PJ,#E___O"NPH``W_
M?EC@L,"G&$``P.L``/``[.$`#X!VN00`*,#E___P.+D$`"C`Y?__\'.G]/\Y
MN00`*,#E____!*?T__0'!P<'!P<'!P<'!P<'!^MO\#``)+)/`)#`$```0(/K
M:0`@``WCH!````2R3P!AN00`[^/P_UC_<>/@\```),1(``!`=.,J8```!+D$
M`+_`4```,VC`,```$Q+`Y?__\(KE2/"@``#C*F````3`0```#Z'`8```%&K`
M,```$PZY!`!6P.7__^[FZV^PV``$!_X'!P<'!P<'!P<'!P<'!^MO\#``)+)/
M`*"Y!`#OZZH`(``-X_#_6/YQX^#P```DLD\`H;D$`+_C$+"@`7&Y!`"#09"P
MH-('$`"@*+D$`'*Y!``YITD/_\`@```2XL#E___N4>PL`!(`?NP"__\`V!@2
MN10`($$RL*"5`#``IW0`(NP&`!\`?L!```!`!.-00```!+D$`#?C):````2Y
M!`!(P.7__^WOXY"PH`%QU0>0`*`HIW0`*>MOL-@!!`?^&!"Y%`!AN00`*;D$
M`$:G.0`OP.7__^XG["C_V`!\P.```#_9XX#@```$N00`5N,HH```!+D$`$FY
M!``WP.7__^["I_3_T\#E___O'0<'!P?K;_`P`"2R3P!@N00`[^MF`"``#;)/
M`&'C\/\X_W'CX/```"2Y!`"_T@>PP&`HN00`HKD$`).5/3``IW0`!$&0,`&G
M&0``[#D\OP!5IX0`>:<I``^Y"0`CYP*0```WIQL`$.<@`#``@:>$``SG`9``
M0`:G&P`0YR``,`"!IW3_^.<"``<`(4%`(`&YA`!0N2``4KGB(!2G)`!4XW%?
M\/]QN00`*N-PL+``)$$PL+S`Y?___1&Y!`""["@`2P!\I]D``.P"/+\`5:>$
M`#^G>0`/N0D`<.='(```-Z?;`!#G9$`P`(&GA``,YTV``$`&I]L`$.=D0#``
M@:=T__CG%@`'`"%!,'`!N80`X;D@`.>YXB#3IR0`&N,@L+``!.--[_#_<>PD
M`1#`9>.`L+P`%,38```_$>MX``,`#:?T`%RG*0`/I_3_E:=Y``^G]/_/Q-@`
M`#\!XW#0```$XQ!P```"IX0`Y[D$`!>GB```&.BGB@`!01`0".,P$````J=T
M__BGZ@`#N10`/NLC``,`#>,@L*``),!````_7N,00```$J>$`)KC,+"@``2Y
M!``GP.7__^UAXR"PJ``DXR#0```D["@`?0!\N10`Z.M^``,`#>-`L*@`!%"`
ML+RGB@`!N10`B.LH``,`#4%20`#E2%````#C`*```)2Y!`!:E0"@`*=T``VG
M]`"105!0`>,`4```E)4`4`"GA``%[`;_]SU^N0D`6KD4`!7C,+"P``2Y!`"'
M02,0`N.`T```",#E___L*N,@@```).PH`#D`?./@T```!.,@H```D.-WX```
M!$&@H`%"('``&$+L)@`0`'RG]``NX]"@``"00:"@`4+04`$83>S8`"0`?$)`
ML+"Y!`!7E3VPL$%P<`&G=/_MDCU0`*<9``#C`9```)!"`5`!IQL``>P&__D`
M?-4'L,!@**=T`#[K;[#X``0'_KD$`%>G]/_GXR"PH``$P%```#Z[Y4Q0```!
MP.7__^O5XR"PJ``D["C_Y`!\XU"PH``$N00`-[D4`'CK=P`#``VY!`!'P.7_
M_^YPXQ"PJ``$XQ#0```DI_3_5Z<9``"G]/]_Y4BPH``0IX@``*?T_R[`Y?__
M[7JG.0``X^.0``"00N.``*<[``'LYO_Y`'RG]/^P!P>R3P`@P!```#X.ZU(`
M(``-XS`0```$LD\`4;/!``NY!`"_XR-0```$Q$@``#X`L\T`L,!0```P]\`P
M```0H<#T___N&0<'!P<'!P<'!P<'!^MO\#``)+)/`("Y!`#OZX@`(``-X_#_
M2/UQX^#P```DLD\`@;D$`+_C$+"P`G'CH+"O`7'2!Q``@"C`Y?__[./`````
M$)SC`/"@`"2Y!`!BITD0`:<Y``*Y!``JP%```!"(P.7__^W/N00`*D%@L*ZG
M21``N00`-L#E___KY.PD`#$`?NQR``$`V+D$`**Y%`!WN00`)\#E___K);D$
M`)+L*``2`'RY%`"JN00`5[D$`#:Y!`!*P.7__^N502J0`)(`(`#C,+"P`G'5
M!S``@"BG=``,N00`*>MOL.@"!`?^IYD``*?T__#`Y?__[,P'![/!``NY!`"_
ML\T`L,#T____@@<'!P<'!P<'!P<'!P<'ZV_P,``DLD\`T+D$`._KW0`@``WC
M\/ZH_G'CX/```"2R3P#1N00`O^,0L5`!<;D$`)*Y!`"#T@<0`-`H03"PO,`@
M```0%\#E___ZY:<Y`"^Y!`"BN00`*<#E___LG.PH`!D`?,`@```0"KD$`#G`
MY?___6FY!``IXW"Q4`%QU0=P`-`HIW0!G.MOL8@!!`?^N00`*,#E___KGL`P
M```/]L#E___JZ+D$`&+L*/_=`'SL>3R_`%5!`+#`XP"PL``D08"Q4)4`8`"G
MA`"V[*@`#P!\IP@``+D$`#:Y!``JLET`,J<4__ZGA`"6IUD``.Q&/+\`5:>$
M`2>GZ0`/N0D`Y.<.8```-Z=;`!#G(``P`(&GA``,YP5@`$`&IUL`$.<@`#``
M@:=T__CG$@`'`"%!`.`!N80`,;D@`#ZYXB!0IR0!`N,U/_#_<>/C;___<>QN
M`'^@9;GI8"ZG(0`!IX0`#I4OX`"G=`#SD@#@`./@[___<>QN`!F`9.M2``$`
M#)4OX`"G=`#DD@#@`.LO[___5:=T`-WK`.___U+CX._^_W&G5__OIVD``.Q>
M/+\`5:>$`0.G&0`/N0D`%><1X```-Z=K`!#G,1`P`(&GA``,YQ;@`$`&IVL`
M$.<Q$#``@:=T__CG0P`'`"%!`!`!N80`)+D@`"&YXB!@IR0`WN,V+_#_<;D$
M`&ZG]``CE0"@`:=T`!K`,```#SJG*0``P.7__^HJN00`8NPH_Q\`?)4`8`"G
M=/].[*@`!P!\E2Z@`*>$_^:G.0`!P&````\3I^D``.QX`'4`?*<9``^Y"0`7
MYU&0```WI^L`$.=U4#``@:>$``SG7I``0`:GZP`0YW50,`"!IW3_^.='``<`
M(4%0$`&YA``DN2``(;GB(.6G)`!/X^XO\/]Q00XP`:<Y#__L`_[;(&7CD/"H
M`"3`$```#N?C$/"@`"2G.0`"N00`*,!0```/4Z=)$`#`Y?__[`SC,+"P``2Y
M!``HP.7__^I$[";_D@!^6&"PV*5/@`#`:P``\`#L9/^(8':Y!``HISD``<#E
M___KX.PF_WX`?KD$`#C`(```#JS`Y?___`VY!``HP.7__^I0I_3^H:<9``^G
M]/^:I^D`#Z?T_N>GZ0``[$8\OP!5IX0`+*<9``^Y"0`4YT%@```WI^L`$.=D
M0#``@:>$``SG3F``0`:GZP`0YV1`,`"!IW3_^.<&``<`(4$@$`&YA``PN2``
M,;GB(.*G)``'XSX_\/]QI_3_4J<9``^G]/_BIQD`#Z?T_PO`Y?__ZMH'!P<'
M!P<'!P<'!P<'!^NO\%``)+D$`._C\/]@_W'CX/```"2Y!`"BN00`OZ<Y`"_`
MY?__ZU_L*``%`'Q!H"`!N00`*NNOL/``!,#T___IX@<'!P<'!P<'!P<'!P<'
MZX_P0``DLD\`H+D$`._KJ@`@``VR3P"AX_#_6/YQX^#P```DN00`O^,0L*`!
M<=('$`"@*.PH`)D`?+D$`#*5`"``IX0`DJ>)``#L0CR_`%6GA`"'IRD`#[D)
M`"3G`C```#>GBP`0YR``,`"!IX0`#.<(,`!`!J>+`!#G(``P`(&G=/_XYP(`
M!P`A05`@`;F$`)"Y(`"2N>(@A:<D`&+CB)_P_W&GZ1``[$@``0#9[$X`;2!E
M09"PH+D$`"G`Y?__ZVKC&)___W'L&0`KP&6YZ9`QIQ$``:>$``Z5+Q``IW0`
M()(`$`#C$!___W'L&0`9@&3K0P`!``R5+Q``IW0`$9(`$`#K+Q___U6G=``*
MZP`?__]2XQ`?_O]QIT?_[[D$`"FG.0`OP.7__^JU["@`'0!\["D`!<!ED@`@
M`+D$`"G`Y?__Z3CC4+"@`7'5!U``H"BG=``?ZX^PZ`$$!_ZG*0`/I_3_A^,@
ML*`!<=4'(`"@**=T``_`(```#6OKC[#H`03`]/__Z1>G*0``I_3_W<#E___I
MX`<'!P<'!P<'!P?KG_!(`"2R3P"0N00`[^N9`"``#;)/`)'C\/]0_W'CX/``
M`"2Y!`"_T@>PJ)`H0:"PI+D$`#K`(```#4K`Y?__^`KL*``N`'S$2```.D3C
M(+"D`!3K$@`#``WC$$````CC4!`(``3C4!```"3L6/_C`'SC`!`0``1!$!`(
MXP`0```D[`;_^`!\N00`.L`@```-'\#E___WW^PF_]@`?+D$`#K`(```#1G`
MY?__]]3L*``N`'S$6```.@[C$+"D`!3KX0`#``WCX%````CC`.`(``3C`.``
M`"3L"/_C`'SC,.`0``1!X.`(XS#@```D[#;_^`!\N00`.L`@```,[L#E___W
MJ>PF_]@`?+D$`#K`(```#.?`Y?__]Y[L*``N`'S$6```.=CCX+"D`!3K3@`#
M``WC0%````CC,$`(``3C,$```"3L./_C`'SC($`0``1!0$`(XR!````D[";_
M^`!\N00`.L`@```,O,#E___W<^PF_]@`?+D$`#K`(```#+;`Y?__]VCL*``N
M`'S$.```.:+C(+"D`!3K$@`#``WC$#````CC0!`(``3C0!```"3L2/_C`'SC
M`!`0``1!$!`(XP`0```D[`;_^`!\N00`.L`@```,B\#E___W/>PF_]@`?+D$
M`#K`(```#(3`Y?__]S+L*``N`'S$2```.6SC$+"D`!3K40`#``WC4$````CC
M`%`(``3C`%```"3L"/_C`'SCX%`0``1!4%`(X^!0```D[.;_^`!\N00`.L`@
M```,6<#E___W!^PF_]@`?+D$`#K`(```#%;`Y?__]OSL*``N`'S$2```.3;C
M4+"D`!3K-0`#``WC,$````CCX#`(``3CX#```"3LZ/_C`'SC(#`0``1!,#`(
MXR`P```D[";_^`!\N00`.L`@```,*\#E___VT>PF_]@`?+D$`#K`(```"_C`
MY?__]L;L*``N`'S$Z```.0#C(+"D`!3K$@`#``WC$.````CC,!`(``3C,!``
M`"3L./_C`'SC`!`0``1!$!`(XP`0```D[`;_^`!\N00`.L`@```+S<#E___V
MF^PF_]@`?+D$`#K`(```"_#`Y?__]I#L*``N`'S$.```.,KC$+"D`!3K00`#
M``WC0#````CC`$`(``3C`$```"3L"/_C`'SC4$`0``1!0$`(XU!````D[%;_
M^`!\N00`.L`@```+Q<#E___V9>PF_]@`?+D$`#K`(```"[_`Y?__]EKL*``N
M`'S$.```.)3C0+"D`!3KY``#``WCX#````CC4.`(``3C4.```"3L6/_C`'SC
M(.`0``1!X.`(XR#@```D[";_^`!\N00`.L`@```+E,#E___V+^PF_]@`?+D$
M`#K`(```"X[`Y?__]B3L*``N`'S$6```.%[CX+"D`!3K'@`#``WC$%````CC
M(!`(``3C(!```"3L*/_C`'SC`!`0``1!$!`(XP`0```D[`;_^`!\N00`.L`@
M```+8\#E___U^>PF_]@`?+D$`#K`(```"R7`Y?__]>[L*``N`'S$*```."CC
M$+"D`!3K,0`#``WC,"````CC`#`(``3C`#```"3L"/_C`'SC0#`0``1!,#`(
MXT`P```D[$;_^`!\N00`.L`@```*^L#E___UP^PF_]@`?+D$`#K`(```"R?`
MY?__];BY!``R["@`"0!\P"````L2P.7___A%N00`.L`@```+'<#E___UI;D$
M`#+L*``)`'S`(```"QO`Y?__^#*Y!``ZP"````L9P.7___62N00`,NPH`!H`
M?,`@```*N<#E___X']4'L*B0**=T`"/`,```"[G`(```"LOKG[#X``3`]/__
M^`ZY!``ZP"````K]P.7___5NN00`,NPH_^4`?,`@```*P\#E___W^Z?T_]S`
MY?__YPX'!P<'!P?KK_!0`"2R3P"@N00`[^NJ`"``#;)/`*'C\/]0_W'CX/``
M`"3`(```"J.Y!`"_03"PI-('L*B@*,#E___U/.PH`!P`?+\A(`"GA``7P"<`
M```PN80``KD#`!#L,3^_`5G5!["HH"BY%``CIW0`"NNOL0``!`?^IS@``*?T
M__/`Y?__YLD'!P<'!P<'!P<'!P=@`/"`8"#PB&!`\)!@8/"8ZS_P&``DQ!@`
M`#=ULD\``+D$`._C\/\X_W'CX/```"2Y!`!"ZS``(``-XR`0```$LD\`,;D$
M`+]!X+#(05"PH-('L,`P*./@L+@`).5(L*```>5(L*@``$%@L6CC8+"P`"2G
M.0`"P.7__^95IRD`_\#E___F$`<'!P<'!P<'!P?K;_`P`"2R3P"`N00`[^N(
M`"``#>/P_U#O<>/@\```)+)/`(&Y!`"_XQ"PJ!!QN00`8J=)``+2!Q``@"BG
M.0``P.7__^2H['+__P#9[`<P@`!5['H`#`!\IPO__\`A__\``+F!``*G"P`!
MN0D`<.QT`(P`?$&0L*#`H```-PRY!``WN00`)J=)``#`Y?__Y(/L*`"5_WRY
M!``YN00`)L!!``$`",#E___FANPH`(+_?KD4`#+L/`!@!WWC$Y_X_W'L&0!:
M0&7L03Z_`%75!Q``H`"GA`!HXQ`?__]Q[!D`3$!E[$@`)`!\[$@`%@%\[$@`
M"P)\U0<0`*``IX0`5.,0'___<=4'$`"@`*>$`$SC$!___W'5!Q``H`"GA`!$
MXQ`?__]Q[!D`*$!EU0<0`*``IX0`.>-0'___<;D$`!75!U``H`"GA``OXQ!?
M__]QU0<0`*``IX0`)^,07_[_<=4'$`"@`*>$`!_C$%_]_W'L&?_>H&7"=``!
M``#``?__``#L</]_8&2G*?__XV"PJ!!QU0=@`(`HIW0`&.MOL.`0!`?^N>F0
M(;D(`">G]/_PP"````F-P.7___[>P"````F`P.7___[8P.7__^65!P<'!^N_
M\%@`)+D$`._C\/]@_W'CX/```"2Y!`"_P.7__^-CP.7__^-`["@`!@!\XR`@
M```$Z[^P^``$!_X'!P<'!P?K;_`P`"2R3P"0N00`[^N9`"``#;)/`)'C\/]`
M_W'CX/```"2Y!`!BN00`O\`@```)3$$PL+32!["XD"C`Y?__\Z+L*``:`'RY
M!`"BE0`@`*>$`!.Y!``VP.7__^-D["@`'`!\U0>PN)`HIW0`8^MOL/``!`?^
MU0>PN)`HIW0`6KD$`#;`(```"2#K;[#P``3`]/__]A"G&0``[#8\OP!5IX0`
M1*<I``^Y"0`CYP)@```WIQL`$.<@`#``@:>$``SG`6``0`:G&P`0YR``,`"!
MIW3_^.<"``<`(4%`(`&YA`!0N2``4KGB(!2G)``?XX%?\/]QI^D``.P:/+\`
M5:>$`!RG*0`/N0D`(>="H```-Z?K`!#G9$`P`(&GA``2YTZ@`$`&I_3_]J<I
M``^G]/_*P.7__^38IRD`#Z?T__+G-@`'`"%!`"`!N80`0[D@`$*YXB#@IR3_
M\>->3_#_<4&(4`*Y!``HP.7__^+MXZ#PJ``DP*````A"XZ#PH``DN00`2,!0
M```(L;D$`(*G.0`"P.7__^5HU0>PN)`HIW3_RKD$`#C`(```")#K;[#P``3`
M]/__]8`'!P<'!P<'!P<'ZV_P,``DN00`[^/P_B#_<>/@\```)+)/`-"GZ__X
M8(#@`.O=`"``#;)/`-&Y!`"_T@>QT-`H03"PU.,PL,@`),`0```U0-)'L/@0
M$-(/L.`06-('L/`0:.,@L,``),`@```'X,#E___RKNPH``D`?+D$`)*5`"``
MIW0!@\#E___B,L#E___B#^PH`#@`?.-P(````J>$`#*GZ0``[#<\OP!5IX0`
M)Z<I``^Y"0`CYP)P```WI^L`$.<@`#``@:>$``SG#G``0`:GZP`0YR``,`"!
MIW3_^.<"``<`(4%`(`&YA`!@N2``8KGB(.2GQ`$IIRD`#Z?T_^=!8+#@XR!@
M```"IX0`%N,PL,@`!,#E___R6NPH``<`?)4`(`"G=`#=IVL`".,@8````J=T
M_^ZG*0`-IXD`#<#E___B):>9``VY!`"BL\$`@L!P```'YJ=8`%.Y!`!)N00`
M*KF$`&6G.0`"P%````?=P.7__^2<N2$`B;D$`%FYXJ!8N>F0%:<;``*Y(0`5
MN>)0%;D)`)5!<'`!0:"@`N.9'_[_<>-0<```E)4`<`"G=/_6XZ"PR``$07"Q
M&,`@```'A*?T``FG>P`(XR!_^/\"IX0`(+D$`#K`Y?__\?BY!`!B["C_\@!\
ME0`@`*>$_^W`Y?__\F3L*/_H`'ZY!``FP.7__^+$N00`8NPF`!T`?$&`L/CC
M8(````*GA``5E0!@`*>$`-NY!``FP.7___)'["8`O0!^IXL`".-@@````J=T
M_^^GZ0``[#8\OP!5IX0`P:<I``^Y"0`CYQ)@```WI^L`$.<Q$#``@:>$``SG
M'F``0`:GZP`0YS$0,`"!IW3_^.<#``<`(4%`(`&YA`!0N2``4KGB(.2G)`"<
ML\T`>..>7_#_<:<9``#LISR_`%6GA`,?I^D`#[D)`.KG7G```#>G&P`0YW50
M,`"!IX0`D;/-`#CG43``0`:G]/_TP.7__^)5["C_(@!\N00`<J?I``#L,CR_
M`%6GA`!#IRD`#[D)`"/G0G```#>GZP`0YV1`,`"!IX0`#.=.<`!`!J?K`!#G
M9$`P`(&G=/_XYP8`!P`A04`@`;F$`&"Y(`!BN>(@Y*<D`![CCF_P_W'KF``!
M``VGFP`!N00`*<#E___A%^-0<```E+D$`**5`'``IX0`.;D$`(FSP0""I_3^
M\*<I``^G]/_+P.7___UAU0>QT-`HIW0`*VB`L=BY!``IZV^R$``$P/3__^'R
MN00`)J>+``C`Y?__X>NY!`!B["C_+`!\I^D``.PV/+\`5:=T_T.G*0`/I_3_
M3:=I``"G]/\TL\$`@J?T_N?`Y?__XJ#G)P`'`"%!`.`!N80`0KD@`$ZYXB`0
MIR0"=>-13_#_<1I9IUH$!+D4`*6Y!``JP.7__^"V8(#PL,`0```&#>,0\*``
M),"0```&@>.0\*@`)+D$`'*G.0`"N00`2L!0```&<,#E___C++D$`">G.0'`
MP.7__^(5["8`"_]^P.7__^'?6&`@`.QF`601?D&`L4"SP0"(N00`.+D$`"?`
MY?__XG\8@NPF``T`?EC@L5BG.$``P.L``/``[.,`*(!VQ*@``#+^N00`9^-P
ML,``!.,@H```!.-0<```!,!````&5Z<Y``+`Y?__XDNGF0``U0>QT-`HIW3_
M@[D$`"EH@+'8ZV^R$``$!_Y8D+%<P.7__]_W[)+_UF!V6`"Q6*<H`<#`"P``
M`?_L`O_,8':Y!``JP.7__^`UXS"PR``$N00`DL`@```&3L#E___P2KD$`#+L
M*`#N`'SC0+#```3C($````3`Y?__]32Y!`!B["@`X`!\IQD``.SF/+\`5:>$
M`.6G*0`/N0D`+N<"8``(-Z<;`!#G(``P#H&GA``,YP%@`$@&IQL`$.<@`#`.
M@:=T__CG,@`'!"%!`"`!N80`0[D@`$*YXB`0IR0`P.-13_#_<>Q<`"`#?KD4
M`!7`X```!@3C(6_\_W&G"```LET`XJ<4__ZG=``/[%@!-P1^IUK_^[D4`#5!
M0V``E2]``*>$`2SC,+#(``3`(```!3_`Y?__[]_L*`"S`'SC$"```)3L&`"M
M`'[L&`"J,'[`,```!@K`(```!2K`Y?__\F+`Y?__X3?C(/"H`"2Y!`!GP```
M``3[XP#PH``DP'````8EXW#PL``DN00`2KD$`"G`4```!<>G.0`"P.7__^(:
MI_0`,,#E___@U5@P(`"G/@`1IW0`,<#E___A#.,@\*@`),!0```&`N-0\+@`
M)*>*``'`````!,KC`/"@`"2Y%``8XQ#PL``DN00`2KD$`"G`4```!9ZG.0`"
MP.7__^'JN00`*:<Y`<#`Y?__X-/L*/_+_WZY!`!VN00`)\#E___AF;D$`#G`
M(```!)/`Y?__\?FY!``IP.7___N<I_3^X^-0L,``!*<9``#C8%````3LYCR_
M`%6G=/\?IRD`#Z?T_RGC0+#```3$*```,;.Y%`!FXV#PH``DXU!````$XR`@
M```$N00`9\!````$[*<Y``+`Y?__X/ZG]/ZSN00`)J<Y``#`Y?__X66Y!`!B
M["C_4`!^P.7___I5XR"PR``DN00`4NPD_T4`?*=)``#C,%_V_W&Y!``FP.7_
M_]\+N00`)D$PL-JG20`&P.7__^$2["8`E@9\P$```"19U05``+#:IW3_)N/@
ML,@`!*=)``#C,._._W&Y!``FP.7__][JL\T`.+D$`":G20`HP.7__^#Q["8`
M=2A\8(#PJ,`P```%1>,P\+``),"````$#^.`\*``))(`L6BY!`!*N00`9[D$
M`"G`4```!-6G.0`"P.7__^$PI_3_4N-0L,``!.,04`@``J>$_M"GZ0``[`$\
MOP!5IX0`/:<I``^Y"0`@YT(0``@WI^L`$.=D0#`.@:>$``SG3A``2`:GZP`0
MYV1`,`Z!IW3_^.<V``<$(4%0(`&YA`!#N2``0KGB(.6G)``8X^Y/\/]Q[.S^
MGP-]XSX?_/]QP"````2%IP@``+)=`".G%/_^N>*`8:?T_HZG*0`/I_3_T:?I
M``^G]/SOP"````1SP.7___E6!P<'!P<'ZV_P,``DLD\`H,"0```PL^NJ`"``
M#>,0D```!+)/`*&Y!`#OX_#_4/]QX^#P```DXX&@```$N00`O]('L*B@*-(`
M@+&`L$%PL*3`(````XJY!``WP.7__^XV["@`!P!\E3$@`*>$`-+`Y?__]@3C
M()````3C@J````2Y!``HIUD``Z=)``'`,```!$7`Y?__WEJY!`""["@`'P!\
MXS`@$``$XV"0```$XS`P```$XR:@```$P$````0OP.7__]Y3XT"`$``$XS!`
M```$D4`P#:=T`+/C8)````2G60`#XR:@```$ITD``<`P```$&,#E___>*;D$
M`(+L*``<`'RY!``WP"````,3P.7__^W<N00`0NPH`($`?.,0@!``!.,FH```
M!.,P$```!,#E___>&^.0D```!*=)``'C::````3`,````^VY!``FP.7__]U;
MP$````/PN00`,KD$`";`Y?__W@'C*:````2Y!``WD@`@L<`@```"UL#E___M
MI,0K```P:;D$`'+L*``L`'RY!``GISD!P,#E___>]>P"``$`V.P,`!8!?^PH
M`!,1?L2H```P3;D$`%+C,*````2Y!`!'P"````/+P.7__]]\U0>PJ*`HIW0`
M.>MOL.``!`?^Q"@``#`TP.7___J-Q"L``#`RN00`<NPF_\P`?,`@```#G<#E
M___?7Y4`(`&GA/\WI_3_+.-0@!``!,3H```P%^,@4```!.,PX```!,#E___O
M8J?T_W_C)J````3`Y?__WN*G]/])P.7__][M!P<'!^N/\$``)+)/`)"Y!`#O
MZYD`(``-LD\`D>/P_U#_<>/@\```)+D$`**Y!`"_P"````)_03"PI-('L*B0
M*,#E___M&NPH`!,`?.,0(```E.P8``T`?NP8``HP?NRH``<`?)4`H`"G=``+
MU0>PJ)`HIW0`-.N/L/``!`?^N00`*L#E___T`:<Y`"^Y!`""P.7__]]"["@`
M!0!\08`@`;D$`"C`Y?__W<BG20`$P#````*9P.7__]U0[";_V0!^U0>PJ)`H
MIW0`"KD$`"KKC[#P``3`]/__[9C`Y?__WGT'!P<'Z[_P6``DP-```"(!N00`
M[^/P_V#_<>/@\```)+D$`+^G*0"`P.7__]R6YP#0(#`&YR#0$#`&YT#0`#`&
MYP`@`#`.YR`@$#`.YT`@(#`.Y4@@,```Y4P@>```Z[^P^``$!_X'!P<'!P<'
M!P<'!P<'!^MO\#``)+D$`._C\/]8_W'CX/```"3C4"`H``2Y!`"2ZQ0``P`-
MN0@`%>PA(+\`5;D$`(2Y!`"_XT"0,``$N00`H[DQ`%&GQ``$ITL``>L(`!T`
M#+D(``3G`@```&+CX)!X`!+G`)`H,`ZG=`!#07"0..R,`&@_?NQ8_\``V.L5
M``8`WE`0L*3L00`!`-CLY!^Y!EGL#O_``-E!WJ``ZV``!@`,IVL``=(_<`"@
M`+D$`"E!H*!`P.7__^#]IV?_]E@@L*2GBO_`B2``!AN"N10`B+D$`#VY!``G
MN00`2,#E___>\5"`D'CK;[#8``0'_J=H`$`;;AEH07"0.+GR,&BY!``GN1@`
M+KD$`#JY%`#6N00`3<#E___>UA@V6C"0>%`PD'CL-O_B0'X;AKD$`"FY"`"M
MN10`B,#E___@O*?T_YJY!`#:I_3_Q@<'!P<'!^M_\#@`),#0```A.;D$`._C
M\/]@_W'CX/```"2Y!`"_XX`P*``$N00`H^-P,#``!.PX.K\]6;D4`!-!0:`X
MDH!``*<Z``&Y!`"201"@.+D4`".Y"``2[#P`:3A^IT@`0+GY,"3L0P`0@':G
M*O__ZP(`"`#>[`8`>0!^N18`4L90````?;D$`"K`Y?__X&S7-Z`XH#AH`-``
MZ^<`$``,ZQ<`&``,ZS<`"``,ZT@`&``,ZR@`"``,YP$````BYPX``0`BYP,`
M`@`BYP<``P`BZW@`$``,YP0`!``BYP<`!0`BYP(`!@`BYP@`!P`B8`"@<+D$
M`"K`Y?__X#;2`Y``H`2Y!``JT@.0!*`,T@.0"*`4T@.0#*`<T@.0$*`DZW^P
MV``$P/3__]V'IP@`.+GY,%#L`_^R@':G6O__Z^4`"`#>[.8`"@!^N18`-<8P
M````&J?T_Z+7_Q``$`!!$!$`I^;_^Z?T__+7_Q``$`!!$!$`IP;_^Z?T_X/7
M`!``$`#7`!``$``'!P<'!P<'!P<'!P?$6```+9S`]/__VPT'!P<'ZV_P,``D
MXQ#P>``$I_O_8.,0\```),#````L9>-`\1``!.MO\-``!`?T``````````(`
M`25S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5```+W!R;V,O<V5L9B]E>&4``"]P<F]C+R5I+R5S`&5X90`N
M`%!!4E]414U0``!005)?4%)/1TY!344``#H`+P!015),-4Q)0@``4$523$Q)
M0@!015),-4]05```4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$
M14)51P``4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@``4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``&QS965K(&9A:6QE9```<F5A9"!F
M86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>```)7,E<R5S)7,`
M`'!A<BT``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H``%!!5$@``'!A<FP``"YP87(``'-H;W)T(')E860`
M`"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U
M)7,``!@`<&5R;```,`!005(Z.E!A8VME<CHZ5D524TE/3@``,2XP-C$`56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H``"UE```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?
M;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@
M("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-
M04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM
M>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@
M+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@
M:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P
M*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD
M97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D
M:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D
M=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D
M=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N
M86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q
M6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A
M;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G
M;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@
M4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#
M04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD[
M"FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@
M>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*
M?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?
M1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP
M86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)
M3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L
M("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H
M92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)
M3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[
M)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN
M9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H
M+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS
M965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*
M)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE
M(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("10
M2UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%
M('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*
M?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@
M(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T
M85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I
M;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID
M:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E
M<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D
M;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI
M('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX[
M"GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*
M?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO
M?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T
M96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D
M97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H
M<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT
M(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I
M+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@
M)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z
M:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T
M(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP
M<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE
M7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@
M)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP
M0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-
M04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A
M:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*
M?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G
M;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N
M($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T
M<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@
M=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D
M9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A
M9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ
M92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@
M/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L
M;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B
M)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D
M=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@
M)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@
M)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!54T52``!5
M4T523D%-10``5$5-4$1)4@!435``+W1M<`````````````##TN'P````````
M````````F+K<_@`````0,E1V`````&=%(P$`````[\VKB0``````````<&5R
M;'AS:2YC``!#04-(10```````````1L#.P```.P````<__]Z^```!K#__WV8
M```!"/__?L@```$X__^5.````7S__Y8H```!X/__EL@```(8__^8V````EC_
M_YEH```"F/__FF@```+8__^=R````QS__YX8```#./__GP@```-X__^?*```
M`Y3__Z+X```#U/__HT@```0$__^DZ```!%#__ZJ(```$B/__JQ@```2\__^K
MJ```!.S__ZUX```%,/__K;@```5@__^O>```!<3__[AX```&(/__NL@```9D
M__^[J```!O3__[P8```')/__O6@```=D__^^^```!Z@`````````%``````!
M>E(``7@.`1L,#Z`!!PX`````%````!S__WR(````0@``````````````%```
M```!>E(``7@.`1L,#Z`!````````0````!S__WV(```69@!*A@Z'#8@,B0N*
M"HL)C`B-!XX&CP54#M@'2@T+`Q8V"L_.S<S+RLG(Q\8,#Z`!0@L```````!@
M````8/__D[0```#J`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4H.P`)*#0L"F`K/
MSLW,R\K)R,?&#`^@`4(+7`K/SLW,R\K)R,?&#`^@`4(+3@K/SLW,R\K)R,?&
M#`^@`4(+````-````,3__Y1`````G@!&B0N*"HL)C`B-!XX&CP58#M@#3@T+
M`FH*S\[-S,O*R0P/H`%""P`````\````_/__E*@```("`$:&#H<-B`R)"XH*
MBPF,"(T'C@:/!5@.X`-*#0MH"L_.S<S+RLG(Q\8,#Z`!0@L`````/````3S_
M_Y9X````@@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5D#L@"5@T+`D#/SLW,R\K)
MR,?&#`^@`0```````#P```%\__^6R````/P`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%5`[((DX-"P*&"L_.S<S+RLG(Q\8,#Z`!0@L```!````!O/__EX@```->
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!5@.Z`)*#0L#`J(*S\[-S,O*R<C'Q@P/
MH`%""P```````!@```(`__^:I````$0`7@D+$$0-"U#+#0\````\```"'/__
MFM@```#N`$:&#H<-B`R)"XH*BPF,"(T'C@:/!50.V$).#0L"M@K/SLW,R\K)
MR,?&#`^@`4(+````&````ES__YN(````$@!$"0L01`T+1,L-#P```#P```)X
M__^;C````\(`1H8.APV(#(D+B@J+"8P(C0>.!H\%5`[X(TX-"P)F"L_.S<S+
MRLG(Q\8,#Z`!0@L````L```"N/__GQP```!"`$:*"HL)C`B-!XX&CP5*#L`"
M3@T+7L_.S<S+R@P/H`$```!(```"Z/__GSP```&6`$:(#(D+B@J+"8P(C0>.
M!H\%6`[((DH-"P,!-`K/SLW,R\K)R`P/H`%""V0*S\[-S,O*R<@,#Z`!1@L`
M````-````S3__Z"0```%F@!&B0N*"HL)C`B-!XX&CP58#M`"2@T+`P4\"L_.
MS<S+RLD,#Z`!1@L````P```#;/__I?@```"$`$:*"HL)C`B-!XX&CP58#M`"
M4`T+`D8*S\[-S,O*#`^@`4(+````+````Z#__Z94````A@!@A@Z'#8@,B0N*
M"HL)C`B-!XX&CP5*#N@"7@T+````````0````]#__Z:T```!S`!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP54#M""!$X-"P,!>`K/SLW,R\K)R,?&#`^@`4(+````
M```L```$%/__J$`````Z`$:+"8P(C0>.!H\%2@[``DH-"U[/SLW,RPP/H`$`
M``````!@```$1/__J%````&V`$:&#H<-B`R)"XH*BPF,"(T'C@:/!5@.X`).
M#0L"2`K/SLW,R\K)R,?&#`^@`4(+6@K/SLW,R\K)R,?&#`^@`48+`P$:S\[-
MS,O*R<C'Q@P/H`$`````6```!*C__ZFL```(^@!&A@Z'#8@,B0N*"HL)C`B-
M!XX&CP5*#H`%8`T+F!4#`VP*S\[-S,O*R<C'QM@,#Z`!1@L#`4H*S\[-S,O*
MR<C'QM@,#Z`!0@L```````!````%!/__LE````),`$:&#H<-B`R)"XH*BPF,
M"(T'C@:/!60.T`)0#0L#`:0*S\[-S,O*R<C'Q@P/H`%""P```````$@```5(
M__^T7````-P`1H@,B0N*"HL)C`B-!XX&CP58#M`"3@T+`DP*S\[-S,O*R<@,
M#Z`!0@L"5@K/SLW,R\K)R`P/H`%&"P````!````%E/__=$````*4`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!50.Z`).#0L#`;@*S\[-S,O*R<C'Q@P/H`%""P``
M`````"P```78__^TK````&(`1HL)C`B-!XX&CP50#L`"2@T+`D#/SLW,RPP/
MH`$``````#P```8(__^T[````4H`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[(
M`F@-"P*V"L_.S<S+RLG(Q\8,#Z`!0@L```!````&2/__M?P```&$`$:'#8@,
MB0N*"HL)C`B-!XX&CP50#L`"2@T+`P$""L_.S<S+RLG(QPP/H`%&"P``````
M`````!````:,__^W2`````P`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````))``````
M```D0``````````!`````````N$``````````0````````+Q``````````P`
M```````9D``````````-````````9.``````````&0```````+NP````````
M`!L`````````"``````````:````````N[@`````````'``````````(````
M`&___O4````````"D``````````%````````#$``````````!@````````-P
M``````````H````````$;0`````````+`````````!@`````````%0``````
M``````````````,```````"]P``````````"````````!2@`````````%```
M```````'`````````!<````````4:``````````'````````$>``````````
M"`````````*(``````````D`````````&``````````>``````````@`````
M;___^P`````(```!`````&____X````````1<`````!O____``````````$`
M````;___\````````!"N`````&____D`````````$```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````N\``````````````````````
M````````&?X````````:'@```````!H^````````&EX````````:?@``````
M`!J>````````&KX````````:W@```````!K^````````&QX````````;/@``
M`````!M>````````&WX````````;G@```````!N^````````&]X````````;
M_@```````!P>````````'#X````````<7@```````!Q^````````')X`````
M```<O@```````!S>````````'/X````````='@```````!T^````````'5X`
M```````=?@```````!V>````````';X````````=W@```````!W^````````
M'AX````````>/@```````!Y>````````'GX````````>G@```````!Z^````
M````'MX````````>_@```````!\>````````'SX````````?7@```````!]^
M````````'YX````````?O@```````!_>````````'_X````````@'@``````
M`"`^````````(%X````````@?@```````"">````````(+X`````````````
M``````````````````````````!>4```````````````````````````````
M````````````````````````````````````````````````````P(``````
M`````````````"#0``````````````````#`"`I005(N<&T*````````````
M``````"E?@```````&5L``````````````````!F#````````&80````````
MI7(```````!E<@```````*5Z``````````````````"E8@```````*5H````
M``````````````!G\D=#0SH@*%5B=6YT=2`Q,RXR+C`M,C-U8G5N='4S*2`Q
M,RXR+C```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N
M;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV
M97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M
M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A
M`"YB<W,`+F-O;6UE;G0`````````````````````````````````````````
M``````````````````````````````````````````````````L````!````
M``````(````````".`````````(X``````````\````````````````````!
M```````````````3````!P`````````"`````````D@````````"2```````
M```D````````````````````!```````````````)@````<``````````@``
M``````)L`````````FP`````````(`````````````````````0`````````
M`````#1O___V``````````(````````"D`````````*0`````````-P````%
M```````````````(```````````````^````"P`````````"`````````W``
M```````#<`````````C0````!@````(`````````"``````````8````1@``
M``,``````````@````````Q`````````#$`````````$;0``````````````
M``````$``````````````$YO____``````````(````````0K@```````!"N
M`````````+P````%```````````````"``````````(```!;;____@``````
M```"````````$7`````````1<`````````!P````!@````$`````````"```
M````````````:@````0``````````@```````!'@````````$>`````````"
MB`````4```````````````@`````````&````'0````$`````````$(`````
M```4:````````!1H````````!2@````%````%0`````````(`````````!@`
M``!^`````0`````````&````````&9`````````9D``````````^````````
M````````````!```````````````>0````$`````````!@```````!G0````
M````&=`````````'``````````````````````0`````````(````(0````!
M``````````8````````@T````````"#0````````1!``````````````````
M```0``````````````"*`````0`````````&````````9.````````!DX```
M```````J````````````````````!```````````````D`````$`````````
M`@```````&40````````91````````!`R`````````````````````@`````
M`````````)@````!``````````(```````"EV````````*78`````````.P`
M```````````````````$``````````````"F`````0`````````"````````
MIL@```````"FR`````````;0````````````````````"```````````````
ML`````X``````````P```````+NP````````N[``````````"```````````
M``````````@`````````"````+P````/``````````,```````"[N```````
M`+NX``````````@````````````````````(``````````@```#(````!@``
M```````#````````N\````````"[P`````````(`````!@``````````````
M"``````````0````T0````$``````````P```````+W`````````O<``````
M```"0`````````````````````@`````````"````-8````!``````````,`
M``````#``````````,```````````(@````````````````````(````````
M``````#<````"``````````#````````P(@```````#`B``````````H````
M````````````````"```````````````X0````$`````````,```````````
M````````P(@`````````)@````````````````````$``````````0````$`
M```#`````````````````````````````,"N`````````.H`````````````
.```````!````````````
